@@ -27,7 +27,7 @@ pyAgrum includes :
 #*   Free Software Foundation, Inc.,                                       *
 #*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-__version__ = '0.22.0'
+__version__ = '0.22.3'
 __license__ = __doc__
 __project_url__ = 'http://agrum.org'
 
@@ -39,7 +39,7 @@ from .pyAgrum import statsObj
 from .pyAgrum import Arc, Edge, DiGraph, UndiGraph, MixedGraph, DAG, CliqueGraph
 from .pyAgrum import BayesNet, BayesNetFragment, EssentialGraph, MarkovBlanket
 from .pyAgrum import MarkovNet, ShaferShenoyMNInference
-from .pyAgrum import DiscretizedVariable, LabelizedVariable, RangeVariable, DiscreteVariable
+from .pyAgrum import DiscretizedVariable, LabelizedVariable, RangeVariable, DiscreteVariable, IntegerVariable
 from .pyAgrum import Potential, Instantiation, Potential
 from .pyAgrum import ExactBNdistance, GibbsBNdistance, StructuralComparator
 from .pyAgrum import LazyPropagation, ShaferShenoyInference, VariableElimination
@@ -78,7 +78,7 @@ __all__=[
   'Arc','Edge','DiGraph','UndiGraph','MixedGraph','DAG','CliqueGraph',
   'BayesNet', 'BayesNetFragment', 'EssentialGraph', 'MarkovBlanket',
   'MarkovNet','ShaferShenoyMNInference',
-  'DiscretizedVariable','LabelizedVariable','RangeVariable','DiscreteVariable',
+  'DiscretizedVariable','LabelizedVariable','RangeVariable','DiscreteVariable','IntegerVariable',
   'Potential','Instantiation','Potential',
   'ExactBNdistance','GibbsBNdistance','StructuralComparator',
   'LoopyBeliefPropagation','GibbsSampling','MonteCarloSampling', 'ImportanceSampling', 'WeightedSampling',
@@ -126,7 +126,7 @@ def about():
   about() for pyAgrum
 
   """
-  print("pyAgrum 0.22.0")
+  print("pyAgrum 0.22.3")
   print("(c) 2015-2021 Pierre-Henri Wuillemin, Christophe Gonzales")
   print("""
     This is free software; see the source code for copying conditions.
@@ -530,4 +530,3 @@ def log2(p):
     a pyAgrum.Potential
   """
   return Potential(p).log2()
-
